Changes in Jupyter console
==========================

A summary of changes in Jupyter console releases.

4.0
---

4.0.3
~~~~~

-  fix ``jupyter console --generate-config``

4.0.2
~~~~~

-  setuptools fixes for Windows

4.0.0
~~~~~

First release as a standalone package.
